@@ -1,4 +1,4 @@
-"""CrowdStrike Falcon Event Stream API interface class
+"""CrowdStrike Falcon Event Stream API interface class.
 
  _______                        __ _______ __        __ __
 |   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
@@ -41,7 +41,7 @@ from ._endpoint._event_streams import _event_streams_endpoints as Endpoints
 
 
 class EventStreams(ServiceClass):
-    """The only requirement to instantiate an instance of this class is one of the following:
+    """The only requirement to instantiate an instance of this class is one of the following.
 
     - a valid client_id and client_secret provided as keywords.
     - a credential dictionary with client_id and client_secret containing valid API credentials
@@ -52,6 +52,7 @@ class EventStreams(ServiceClass):
     - a previously-authenticated instance of the authentication service class (oauth2.py)
     - a valid token provided by the authentication service class (OAuth2.token())
     """
+
     @force_default(defaults=["parameters", "body"], default_types=["dict", "dict"])
     def refresh_active_stream(self: object,
                               partition: int = 0,
@@ -60,11 +61,13 @@ class EventStreams(ServiceClass):
                               **kwargs
                               ) -> dict:
         """Refresh an active event stream.
+
         Use the URL shown in a listAvailableStreamsOAuth2 response.
 
         Keyword arguments:
         action_name -- Action to perform. Only allowed value is "refresh_active_stream_session".
-        appId -- Label that identifies your connection. 32 character alphanumeric.
+        app_id -- Label that identifies your connection. Will also accept `appId`.
+                  32 character alphanumeric.
         body -- accepted but not used.
         parameters -- full parameters payload, not required if using other keywords.
         partition -- Instance partition to request data for.
@@ -80,6 +83,8 @@ class EventStreams(ServiceClass):
         """
         if not kwargs.get("action_name", None):
             parameters["action_name"] = "refresh_active_stream_session"
+        if kwargs.get("app_id", None):
+            parameters["appId"] = kwargs.get("app_id", None)
 
         return process_service_request(
             calling_object=self,
@@ -96,7 +101,8 @@ class EventStreams(ServiceClass):
         """Discover all event streams in your environment.
 
         Keyword arguments:
-        appId -- Label that identifies your connection. 32 character alphanumeric.
+        app_id -- Label that identifies your connection. Will also accept `appId`.
+                  32 character alphanumeric.
         format -- format for streaming events. Either 'json' or 'flatjson'.
         parameters -- full parameters payload, not required if using other keywords.
 
@@ -109,6 +115,9 @@ class EventStreams(ServiceClass):
         Swagger URL
         https://assets.falcon.crowdstrike.com/support/api/swagger.html#/event-streams/listAvailableStreamsOAuth2
         """
+        if kwargs.get("app_id", None):
+            parameters["appId"] = kwargs.get("app_id", None)
+
         return process_service_request(
             calling_object=self,
             endpoints=Endpoints,
